summaryrefslogtreecommitdiffstats
path: root/src/usr/initservice/extinitsvc
diff options
context:
space:
mode:
authorDoug Gilbert <dgilbert@us.ibm.com>2011-08-25 10:53:14 -0500
committerDouglas R. Gilbert <dgilbert@us.ibm.com>2011-09-07 10:37:16 -0500
commit6dd3a0514d3754d607be5689bf07a04d3cc8f483 (patch)
tree90428972c1acc0c6b470b83e84b2ece5780a6ad3 /src/usr/initservice/extinitsvc
parentdd8d92217c8cebd6aa5408ad7fd4fa50ea248c84 (diff)
downloadtalos-hostboot-6dd3a0514d3754d607be5689bf07a04d3cc8f483.tar.gz
talos-hostboot-6dd3a0514d3754d607be5689bf07a04d3cc8f483.zip
Move libs to the extended image
Change-Id: I275a3a4b897e6426164e4f3bd642f92b0d3fed07 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/285 Tested-by: Jenkins Server Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Douglas R. Gilbert <dgilbert@us.ibm.com>
Diffstat (limited to 'src/usr/initservice/extinitsvc')
-rw-r--r--src/usr/initservice/extinitsvc/extinitsvc.C3
-rw-r--r--src/usr/initservice/extinitsvc/extinitsvctasks.H102
2 files changed, 86 insertions, 19 deletions
diff --git a/src/usr/initservice/extinitsvc/extinitsvc.C b/src/usr/initservice/extinitsvc/extinitsvc.C
index b5ab6b64e..03bae9364 100644
--- a/src/usr/initservice/extinitsvc/extinitsvc.C
+++ b/src/usr/initservice/extinitsvc/extinitsvc.C
@@ -204,6 +204,9 @@ void ExtInitSvc::init( void *i_ptr )
ENTER_MRK "Run Unit Tests (if libcxxtests.so is present): %s",
l_pcxxtask->taskname );
+ // If the test task does not exist then don't run it.
+ if(!VFS::module_exists(l_pcxxtask->taskname)) break;
+
l_cxxerrl = InitService::getTheInstance().startTask( l_pcxxtask,
&l_cxxtestargs );
diff --git a/src/usr/initservice/extinitsvc/extinitsvctasks.H b/src/usr/initservice/extinitsvc/extinitsvctasks.H
index 351b7d1d1..859e3caee 100644
--- a/src/usr/initservice/extinitsvc/extinitsvctasks.H
+++ b/src/usr/initservice/extinitsvc/extinitsvctasks.H
@@ -36,8 +36,6 @@
namespace INITSERVICE
{
- // TODO all these will eventuall be in BASE_IMAGE instead of BASE_IMAGE
-
const uint64_t MAX_EXT_TASKS = 25;
const TaskInfo g_exttaskinfolist[] = {
@@ -45,31 +43,97 @@ const TaskInfo g_exttaskinfolist[] = {
// ----- Extended Image ------------------------------------------
/**
- * @brief targeting task, initializes extended module area
+ * @brief ecmddatabuffer task,
*/
{
- "libtargeting.so" , // taskname
+ "libecmddatabuffer.so" , // taskname
NULL, // no pointer to fn
{
- START_TASK, // task type
- BASE_IMAGE, // Extended Module
- START_TARGETING_ERRL_ID, // module id
+ INIT_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_ECMDDATABUFFER_ERRL_ID, // module id
+ }
+ },
+
+ /**
+ * @brief hwpf task,
+ */
+ {
+ "libhwpf.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ INIT_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_HWPF_ERRL_ID, // module id
}
},
/**
- * @brief IStep Dispatcher task, runs ISteps
- */
- {
- "libistepdisp.so" , // taskname
- NULL, // no pointer to fn
- {
- START_TASK, // task type
- BASE_IMAGE, // Extended Module
- EXECUTE_ISTEPS_ERRL_ID, // module id
- }
- },
+ * @brief fabi task,
+ */
+ {
+ "libfapi.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ INIT_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_FAPI_ERRL_ID, // module id
+ }
+ },
+
+ /**
+ * @brief hwp task,
+ */
+ {
+ "libhwp.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ INIT_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_HWP_ERRL_ID, // module id
+ }
+ },
+
+ /**
+ * @brief plat task,
+ */
+ {
+ "libplat.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ INIT_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_PLAT_ERRL_ID, // module id
+ }
+ },
+
+ /**
+ * @brief targeting task,
+ */
+ {
+ "libtargeting.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ START_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ START_TARGETING_ERRL_ID, // module id
+ }
+ },
+
+ /**
+ * @brief IStep Dispatcher task, runs ISteps
+ */
+ {
+ "libistepdisp.so" , // taskname
+ NULL, // no pointer to fn
+ {
+ START_TASK, // task type
+ EXT_IMAGE, // Extended Module
+ EXECUTE_ISTEPS_ERRL_ID, // module id
+ }
+ },
+
// ---------------------------------------------------------------
// ----- END OF LIST!!! ---------------------------------------
// ---------------------------------------------------------------
@@ -96,7 +160,7 @@ const TaskInfo CXXTEST_TASK = {
NULL, // no pointer to fn
{
START_TASK, // task type
- BASE_IMAGE, // Extended Module
+ EXT_IMAGE, // Extended Module
START_CXXTEST_ERRL_ID, // module id
}
};
OpenPOWER on IntegriCloud